"use strict";
exports.__esModule = true;
var yargs = require("yargs");
var fs = require("fs-extra");
var main_1 = require("./main");
var argv = yargs
    .usage("$0 --from <export file or space> --to <export file or space>")
    .option('from', {
    alias: 'f',
    demandOption: true,
    description: 'A contentful export file, or Contentful Space ID'
})
    .option('to', {
    alias: 't',
    demandOption: true,
    description: 'A contentful export file, space ID, or environment within the "from" space'
})
    .option('out', {
    alias: 'o',
    description: 'The output directory in which to place the migration'
})
    .option('token', {
    alias: 'a',
    description: 'A Contentful management token to download content types from a space'
})
    .option('one-file', {
    description: 'Write all the migrations in a single file'
})
    .argv;
if (!argv.out) {
    if (fs.existsSync('./db/migrate/')) {
        argv.out = './db/migrate/';
    }
    else {
        argv.out = './';
    }
}
fs.mkdirp(argv.out);
main_1["default"]({
    from: argv.from,
    outDir: argv.out,
    to: argv.to,
    managementToken: argv.token || process.env['CONTENTFUL_MANAGEMENT_TOKEN'],
    oneFile: argv.oneFile
})["catch"](function (err) {
    console.error(err);
});
